'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _styledComponents = require('styled-components');

var _styledComponents2 = _interopRequireDefault(_styledComponents);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _theme = require('../../utils/theme');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var StyledAlert = _styledComponents2.default.div.withConfig({
  displayName: 'Alert__StyledAlert'
})(['background:', ';border-radius:', ';border:2px solid ', ';color:', ';margin:8px 0 8px 0;min-height:1em;opacity:', ';padding:1em;transition:opacity 0.2s linear;a{color:', ';text-decoration:underline;&:hover{text-decoration:none;}}'], (0, _theme.fromAtoms)('Alert', 'type', 'background'), function (props) {
  return props.theme.borderRadius.soft;
}, (0, _theme.fromAtoms)('Alert', 'type', 'borderColor'), (0, _theme.fromAtoms)('Alert', 'type', 'color'), function (props) {
  return props.visible ? '1' : '0';
}, (0, _theme.fromAtoms)('Alert', 'type', 'color'));

var CloseIcon = _styledComponents2.default.i.withConfig({
  displayName: 'Alert__CloseIcon'
})(['float:right;cursor:pointer;display:', ';margin-left:1em;'], function (props) {
  return props.visible ? 'block' : 'none';
});

/**
 * An alert to let the user know about an action or state.
 * ```javascript
 * import { Alert } from 'weaveworks-ui-components';
 *
 * export default function() {
 *  return (
 *    <div>
 *     <Alert type="warning" visible={true}>
 *       Warning: Hmm, this is not good, but it is not terrible.
 *     </Alert>
 *    </div>
 *   )
 * }
 * ```
 */
function Alert(props) {
  var onClose = props.onClose,
      children = props.children,
      visible = props.visible;

  return _react2.default.createElement(
    StyledAlert,
    props,
    children,
    onClose && _react2.default.createElement(CloseIcon, {
      visible: visible,
      onClick: onClose,
      className: 'fa fa-remove'
    })
  );
}

Alert.propTypes = {
  /**
   * Set the color scheme to indicate the nature of the alert.
   */
  type: _propTypes2.default.oneOf(['default', 'info', 'success', 'warning', 'error']),

  /**
   * Toggle whether the alert is shown
   */
  visible: _propTypes2.default.bool,
  /**
   * Callback that runs with the alert is dismissed by clicking the 'X'
   */
  onClose: _propTypes2.default.func
};

Alert.defaultProps = {
  type: 'default',
  visible: true
};

exports.default = Alert;